==> 0.0.1.tar.gz: test/test_Core.dart <==
import 'package:unittest/unittest.dart';
import '../lib/dartscale.dart';

class TestModule {
  
  Sandbox sandbox;
  
  TestModule(Sandbox this.sandbox);
  
  void start(Sandbox sandbox) {}
  
  void stop() {}
  
}

main () {
  test("Can register Module", () {
    var core = new Core();
    
    core.register(new TestModule(null));
    
    expect(core.registered("TestModule"), equals(true));
  });
  
  test("Can register multiple Modules", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "ModuleNameOne");
    core.register(new TestModule(null), "ModuleNameTwo");
    
    Iterable registeredModules = core.registered();
    
    expect(registeredModules.contains(new Symbol("ModuleNameOne")), equals(true));
    expect(registeredModules.contains(new Symbol("ModuleNameTwo")), equals(true));
  });
  
  test("Can register Module with custom Name", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "NewName");
    
    expect(core.registered("NewName"), equals(true));
  });
  
  test("Can unregister Module", () {
    Core core = new Core();
    
    core.register(new TestModule(null));
    core.unregister("TestModule");
    
    expect(core.registered("TestModule"), equals(false));
  });
  
  test("Can unregister Module with custom Name", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "NewName");
    core.unregister("NewName");
    
    expect(core.registered("NewName"), equals(false));
  });
  
  test("Can start Module", () {
    Core core = new Core();
    TestModule testModule = new TestModule(null);
    
    core.register(testModule);
    core.start("TestModule");
    
    expect(core.running("TestModule"), equals(true));
  });
  
  test("Can start multiple Modules", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "ModuleNameOne");
    core.register(new TestModule(null), "ModuleNameTwo");
    
    core.startMany(["ModuleNameOne", "ModuleNameTwo"]);
    
    expect(core.running("ModuleNameOne"), equals(true));
    expect(core.running("ModuleNameTwo"), equals(true));
  });
  
  test("Can start all Modules", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "ModuleNameOne");
    core.register(new TestModule(null), "ModuleNameTwo");
    core.register(new TestModule(null), "ModuleNameThree");
    
    core.startAll();
    
    expect(core.running().length, equals(3));
    expect(core.running("ModuleNameOne"), equals(true));
    expect(core.running("ModuleNameTwo"), equals(true));
    expect(core.running("ModuleNameThree"), equals(true));
  });
  
  test("Can stop Module", () {
    Core core = new Core();
    TestModule testModule = new TestModule(null);
    
    core.register(testModule);
    core.start("TestModule");
    core.stop("TestModule");
    
    expect(core.running("TestModule"), equals(false));
  });
  
  test("Can stop multiple Modules", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "ModuleNameOne");
    core.register(new TestModule(null), "ModuleNameTwo");
    
    core.startMany(["ModuleNameOne", "ModuleNameTwo"]);
    core.stop(["ModuleNameOne", "ModuleNameTwo"]);
    
    expect(core.running("ModuleNameOne"), equals(false));
    expect(core.running("ModuleNameTwo"), equals(false));
  });
  
  test("Can stop all Modules", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "ModuleNameOne");
    core.register(new TestModule(null), "ModuleNameTwo");
    core.register(new TestModule(null), "ModuleNameThree");
    
    core.startAll();
    core.stop();
    
    expect(core.running().length, equals(0));
    expect(core.running("ModuleNameOne"), equals(false));
    expect(core.running("ModuleNameTwo"), equals(false));
    expect(core.running("ModuleNameThree"), equals(false));
  });
}

==> 0.0.2.tar.gz: test/test_Core.dart <==
import 'package:unittest/unittest.dart';
import '../lib/dartscale.dart';

class TestModule {
  
  Sandbox sandbox;
  
  TestModule(Sandbox this.sandbox);
  
  void start(Sandbox sandbox) {}
  
  void stop() {}
  
}

main () {
  test("Can register Module", () {
    var core = new Core();
    
    core.register(new TestModule(null));
    
    expect(core.registered("TestModule"), equals(true));
  });
  
  test("Can register multiple Modules", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "ModuleNameOne");
    core.register(new TestModule(null), "ModuleNameTwo");
    
    Iterable registeredModules = core.registered();
    
    expect(registeredModules.contains(new Symbol("ModuleNameOne")), equals(true));
    expect(registeredModules.contains(new Symbol("ModuleNameTwo")), equals(true));
  });
  
  test("Can register Module with custom Name", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "NewName");
    
    expect(core.registered("NewName"), equals(true));
  });
  
  test("Can unregister Module", () {
    Core core = new Core();
    
    core.register(new TestModule(null));
    core.unregister("TestModule");
    
    expect(core.registered("TestModule"), equals(false));
  });
  
  test("Can unregister Module with custom Name", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "NewName");
    core.unregister("NewName");
    
    expect(core.registered("NewName"), equals(false));
  });
  
  test("Can start Module", () {
    Core core = new Core();
    TestModule testModule = new TestModule(null);
    
    core.register(testModule);
    core.start("TestModule");
    
    expect(core.running("TestModule"), equals(true));
  });
  
  test("Can start multiple Modules", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "ModuleNameOne");
    core.register(new TestModule(null), "ModuleNameTwo");
    
    core.startMany(["ModuleNameOne", "ModuleNameTwo"]);
    
    expect(core.running("ModuleNameOne"), equals(true));
    expect(core.running("ModuleNameTwo"), equals(true));
  });
  
  test("Can start all Modules", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "ModuleNameOne");
    core.register(new TestModule(null), "ModuleNameTwo");
    core.register(new TestModule(null), "ModuleNameThree");
    
    core.startAll();
    
    expect(core.running().length, equals(3));
    expect(core.running("ModuleNameOne"), equals(true));
    expect(core.running("ModuleNameTwo"), equals(true));
    expect(core.running("ModuleNameThree"), equals(true));
  });
  
  test("Can stop Module", () {
    Core core = new Core();
    TestModule testModule = new TestModule(null);
    
    core.register(testModule);
    core.start("TestModule");
    core.stop("TestModule");
    
    expect(core.running("TestModule"), equals(false));
  });
  
  test("Can stop multiple Modules", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "ModuleNameOne");
    core.register(new TestModule(null), "ModuleNameTwo");
    
    core.startMany(["ModuleNameOne", "ModuleNameTwo"]);
    core.stopMany(["ModuleNameOne", "ModuleNameTwo"]);
    
    expect(core.running("ModuleNameOne"), equals(false));
    expect(core.running("ModuleNameTwo"), equals(false));
  });
  
  test("Can stop all Modules", () {
    Core core = new Core();
    
    core.register(new TestModule(null), "ModuleNameOne");
    core.register(new TestModule(null), "ModuleNameTwo");
    core.register(new TestModule(null), "ModuleNameThree");
    
    core.startAll();
    core.stopAll();
    
    expect(core.running().length, equals(0));
    expect(core.running("ModuleNameOne"), equals(false));
    expect(core.running("ModuleNameTwo"), equals(false));
    expect(core.running("ModuleNameThree"), equals(false));
  });
}
